# coding: utf-8

"""
    Flat API

    The Flat API allows you to easily extend the abilities of the [Flat Platform](https://flat.io), with a wide range of use cases including the following:  * Creating and importing new music scores using MusicXML or MIDI files * Browsing, updating, copying, exporting the user's scores (for example in MP3, WAV or MIDI) * Managing educational resources with Flat for Education: creating & updating the organization accounts, the classes, rosters and assignments.  The Flat API is built on HTTP. Our API is RESTful It has predictable resource URLs. It returns HTTP response codes to indicate errors. It also accepts and returns JSON in the HTTP body. The [schema](/swagger.yaml) of this API follows the [OpenAPI Initiative (OAI) specification](https://www.openapis.org/), you can use and work with [compatible Swagger tools](http://swagger.io/open-source-integrations/). This API features Cross-Origin Resource Sharing (CORS) implemented in compliance with [W3C spec](https://www.w3.org/TR/cors/).  You can use your favorite HTTP/REST library for your programming language to use Flat's API. This specification and reference is [available on Github](https://github.com/FlatIO/api-reference).  Getting Started and learn more:  * [API Overview and interoduction](https://flat.io/developers/docs/api/) * [Authentication (Personal Access Tokens or OAuth2)](https://flat.io/developers/docs/api/authentication.html) * [SDKs](https://flat.io/developers/docs/api/sdks.html) * [Rate Limits](https://flat.io/developers/docs/api/rate-limits.html) * [Changelog](https://flat.io/developers/docs/api/changelog.html) 

    OpenAPI spec version: 2.2.0
    Contact: developers@flat.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ScoreDetails(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'sharing_key': 'str',
        'title': 'str',
        'privacy': 'ScorePrivacy',
        'user': 'UserPublicSummary',
        'html_url': 'str',
        'rights': 'ScoreRights',
        'collaborators': 'list[ScoreCollaborator]',
        'creation_date': 'datetime',
        'modification_date': 'datetime',
        'organization': 'str',
        'parent_score': 'str',
        'instruments': 'list[str]',
        'google_drive_file_id': 'str',
        'likes': 'ScoreLikesCounts',
        'comments': 'ScoreCommentsCounts',
        'views': 'ScoreViewsCounts'
    }

    attribute_map = {
        'id': 'id',
        'sharing_key': 'sharingKey',
        'title': 'title',
        'privacy': 'privacy',
        'user': 'user',
        'html_url': 'htmlUrl',
        'rights': 'rights',
        'collaborators': 'collaborators',
        'creation_date': 'creationDate',
        'modification_date': 'modificationDate',
        'organization': 'organization',
        'parent_score': 'parentScore',
        'instruments': 'instruments',
        'google_drive_file_id': 'googleDriveFileId',
        'likes': 'likes',
        'comments': 'comments',
        'views': 'views'
    }

    def __init__(self, id=None, sharing_key=None, title=None, privacy=None, user=None, html_url=None, rights=None, collaborators=None, creation_date=None, modification_date=None, organization=None, parent_score=None, instruments=None, google_drive_file_id=None, likes=None, comments=None, views=None):
        """
        ScoreDetails - a model defined in Swagger
        """

        self._id = None
        self._sharing_key = None
        self._title = None
        self._privacy = None
        self._user = None
        self._html_url = None
        self._rights = None
        self._collaborators = None
        self._creation_date = None
        self._modification_date = None
        self._organization = None
        self._parent_score = None
        self._instruments = None
        self._google_drive_file_id = None
        self._likes = None
        self._comments = None
        self._views = None

        if id is not None:
          self.id = id
        if sharing_key is not None:
          self.sharing_key = sharing_key
        if title is not None:
          self.title = title
        if privacy is not None:
          self.privacy = privacy
        if user is not None:
          self.user = user
        if html_url is not None:
          self.html_url = html_url
        if rights is not None:
          self.rights = rights
        if collaborators is not None:
          self.collaborators = collaborators
        if creation_date is not None:
          self.creation_date = creation_date
        if modification_date is not None:
          self.modification_date = modification_date
        if organization is not None:
          self.organization = organization
        if parent_score is not None:
          self.parent_score = parent_score
        if instruments is not None:
          self.instruments = instruments
        if google_drive_file_id is not None:
          self.google_drive_file_id = google_drive_file_id
        if likes is not None:
          self.likes = likes
        if comments is not None:
          self.comments = comments
        if views is not None:
          self.views = views

    @property
    def id(self):
        """
        Gets the id of this ScoreDetails.
        The unique identifier of the score

        :return: The id of this ScoreDetails.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ScoreDetails.
        The unique identifier of the score

        :param id: The id of this ScoreDetails.
        :type: str
        """

        self._id = id

    @property
    def sharing_key(self):
        """
        Gets the sharing_key of this ScoreDetails.
        The private sharing key of the score (available when the `privacy` mode is set to `privateLink`)

        :return: The sharing_key of this ScoreDetails.
        :rtype: str
        """
        return self._sharing_key

    @sharing_key.setter
    def sharing_key(self, sharing_key):
        """
        Sets the sharing_key of this ScoreDetails.
        The private sharing key of the score (available when the `privacy` mode is set to `privateLink`)

        :param sharing_key: The sharing_key of this ScoreDetails.
        :type: str
        """

        self._sharing_key = sharing_key

    @property
    def title(self):
        """
        Gets the title of this ScoreDetails.
        The title of the score

        :return: The title of this ScoreDetails.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this ScoreDetails.
        The title of the score

        :param title: The title of this ScoreDetails.
        :type: str
        """

        self._title = title

    @property
    def privacy(self):
        """
        Gets the privacy of this ScoreDetails.

        :return: The privacy of this ScoreDetails.
        :rtype: ScorePrivacy
        """
        return self._privacy

    @privacy.setter
    def privacy(self, privacy):
        """
        Sets the privacy of this ScoreDetails.

        :param privacy: The privacy of this ScoreDetails.
        :type: ScorePrivacy
        """

        self._privacy = privacy

    @property
    def user(self):
        """
        Gets the user of this ScoreDetails.

        :return: The user of this ScoreDetails.
        :rtype: UserPublicSummary
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this ScoreDetails.

        :param user: The user of this ScoreDetails.
        :type: UserPublicSummary
        """

        self._user = user

    @property
    def html_url(self):
        """
        Gets the html_url of this ScoreDetails.
        The url where the score can be viewed in a web browser

        :return: The html_url of this ScoreDetails.
        :rtype: str
        """
        return self._html_url

    @html_url.setter
    def html_url(self, html_url):
        """
        Sets the html_url of this ScoreDetails.
        The url where the score can be viewed in a web browser

        :param html_url: The html_url of this ScoreDetails.
        :type: str
        """

        self._html_url = html_url

    @property
    def rights(self):
        """
        Gets the rights of this ScoreDetails.

        :return: The rights of this ScoreDetails.
        :rtype: ScoreRights
        """
        return self._rights

    @rights.setter
    def rights(self, rights):
        """
        Sets the rights of this ScoreDetails.

        :param rights: The rights of this ScoreDetails.
        :type: ScoreRights
        """

        self._rights = rights

    @property
    def collaborators(self):
        """
        Gets the collaborators of this ScoreDetails.
        The list of the collaborators of the score

        :return: The collaborators of this ScoreDetails.
        :rtype: list[ScoreCollaborator]
        """
        return self._collaborators

    @collaborators.setter
    def collaborators(self, collaborators):
        """
        Sets the collaborators of this ScoreDetails.
        The list of the collaborators of the score

        :param collaborators: The collaborators of this ScoreDetails.
        :type: list[ScoreCollaborator]
        """

        self._collaborators = collaborators

    @property
    def creation_date(self):
        """
        Gets the creation_date of this ScoreDetails.
        The date when the score was created

        :return: The creation_date of this ScoreDetails.
        :rtype: datetime
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """
        Sets the creation_date of this ScoreDetails.
        The date when the score was created

        :param creation_date: The creation_date of this ScoreDetails.
        :type: datetime
        """

        self._creation_date = creation_date

    @property
    def modification_date(self):
        """
        Gets the modification_date of this ScoreDetails.
        The date of the last revision of the score

        :return: The modification_date of this ScoreDetails.
        :rtype: datetime
        """
        return self._modification_date

    @modification_date.setter
    def modification_date(self, modification_date):
        """
        Sets the modification_date of this ScoreDetails.
        The date of the last revision of the score

        :param modification_date: The modification_date of this ScoreDetails.
        :type: datetime
        """

        self._modification_date = modification_date

    @property
    def organization(self):
        """
        Gets the organization of this ScoreDetails.
        If the score has been created in an organization, the identifier of this organization. This property is especially used with the score privacy `organizationPublic`. 

        :return: The organization of this ScoreDetails.
        :rtype: str
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """
        Sets the organization of this ScoreDetails.
        If the score has been created in an organization, the identifier of this organization. This property is especially used with the score privacy `organizationPublic`. 

        :param organization: The organization of this ScoreDetails.
        :type: str
        """

        self._organization = organization

    @property
    def parent_score(self):
        """
        Gets the parent_score of this ScoreDetails.
        If the score has been forked, the unique identifier of the parent score. 

        :return: The parent_score of this ScoreDetails.
        :rtype: str
        """
        return self._parent_score

    @parent_score.setter
    def parent_score(self, parent_score):
        """
        Sets the parent_score of this ScoreDetails.
        If the score has been forked, the unique identifier of the parent score. 

        :param parent_score: The parent_score of this ScoreDetails.
        :type: str
        """

        self._parent_score = parent_score

    @property
    def instruments(self):
        """
        Gets the instruments of this ScoreDetails.
        An array of the instrument identifiers used in the last version of the score. This is mainly used to display a list of the instruments in the Flat's UI or instruments icons. The format of the strings is `{instrument-group}.{instrument-id}`. 

        :return: The instruments of this ScoreDetails.
        :rtype: list[str]
        """
        return self._instruments

    @instruments.setter
    def instruments(self, instruments):
        """
        Sets the instruments of this ScoreDetails.
        An array of the instrument identifiers used in the last version of the score. This is mainly used to display a list of the instruments in the Flat's UI or instruments icons. The format of the strings is `{instrument-group}.{instrument-id}`. 

        :param instruments: The instruments of this ScoreDetails.
        :type: list[str]
        """

        self._instruments = instruments

    @property
    def google_drive_file_id(self):
        """
        Gets the google_drive_file_id of this ScoreDetails.
        If the user uses Google Drive and the score exists on Google Drive, this field will contain the unique identifier of the Flat score on Google Drive. You can access the document using the url: `https://drive.google.com/open?id={googleDriveFileId}` 

        :return: The google_drive_file_id of this ScoreDetails.
        :rtype: str
        """
        return self._google_drive_file_id

    @google_drive_file_id.setter
    def google_drive_file_id(self, google_drive_file_id):
        """
        Sets the google_drive_file_id of this ScoreDetails.
        If the user uses Google Drive and the score exists on Google Drive, this field will contain the unique identifier of the Flat score on Google Drive. You can access the document using the url: `https://drive.google.com/open?id={googleDriveFileId}` 

        :param google_drive_file_id: The google_drive_file_id of this ScoreDetails.
        :type: str
        """

        self._google_drive_file_id = google_drive_file_id

    @property
    def likes(self):
        """
        Gets the likes of this ScoreDetails.

        :return: The likes of this ScoreDetails.
        :rtype: ScoreLikesCounts
        """
        return self._likes

    @likes.setter
    def likes(self, likes):
        """
        Sets the likes of this ScoreDetails.

        :param likes: The likes of this ScoreDetails.
        :type: ScoreLikesCounts
        """

        self._likes = likes

    @property
    def comments(self):
        """
        Gets the comments of this ScoreDetails.

        :return: The comments of this ScoreDetails.
        :rtype: ScoreCommentsCounts
        """
        return self._comments

    @comments.setter
    def comments(self, comments):
        """
        Sets the comments of this ScoreDetails.

        :param comments: The comments of this ScoreDetails.
        :type: ScoreCommentsCounts
        """

        self._comments = comments

    @property
    def views(self):
        """
        Gets the views of this ScoreDetails.

        :return: The views of this ScoreDetails.
        :rtype: ScoreViewsCounts
        """
        return self._views

    @views.setter
    def views(self, views):
        """
        Sets the views of this ScoreDetails.

        :param views: The views of this ScoreDetails.
        :type: ScoreViewsCounts
        """

        self._views = views

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ScoreDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
