# coding: utf-8

"""
    Flat API

    The Flat API allows you to easily extend the abilities of the [Flat Platform](https://flat.io), with a wide range of use cases including the following:  * Creating and importing new music scores using MusicXML or MIDI files * Browsing, updating, copying, exporting the user's scores (for example in MP3, WAV or MIDI) * Managing educational resources with Flat for Education: creating & updating the organization accounts, the classes, rosters and assignments.  The Flat API is built on HTTP. Our API is RESTful It has predictable resource URLs. It returns HTTP response codes to indicate errors. It also accepts and returns JSON in the HTTP body. The [schema](/swagger.yaml) of this API follows the [OpenAPI Initiative (OAI) specification](https://www.openapis.org/), you can use and work with [compatible Swagger tools](http://swagger.io/open-source-integrations/). This API features Cross-Origin Resource Sharing (CORS) implemented in compliance with [W3C spec](https://www.w3.org/TR/cors/).  You can use your favorite HTTP/REST library for your programming language to use Flat's API. This specification and reference is [available on Github](https://github.com/FlatIO/api-reference).  Getting Started and learn more:  * [API Overview and interoduction](https://flat.io/developers/docs/api/) * [Authentication (Personal Access Tokens or OAuth2)](https://flat.io/developers/docs/api/authentication.html) * [SDKs](https://flat.io/developers/docs/api/sdks.html) * [Rate Limits](https://flat.io/developers/docs/api/rate-limits.html) * [Changelog](https://flat.io/developers/docs/api/changelog.html) 

    OpenAPI spec version: 2.2.0
    Contact: developers@flat.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ScoreModification(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'privacy': 'ScorePrivacy',
        'title': 'str',
        'sharing_key': 'str'
    }

    attribute_map = {
        'privacy': 'privacy',
        'title': 'title',
        'sharing_key': 'sharingKey'
    }

    def __init__(self, privacy=None, title=None, sharing_key=None):
        """
        ScoreModification - a model defined in Swagger
        """

        self._privacy = None
        self._title = None
        self._sharing_key = None

        if privacy is not None:
          self.privacy = privacy
        if title is not None:
          self.title = title
        if sharing_key is not None:
          self.sharing_key = sharing_key

    @property
    def privacy(self):
        """
        Gets the privacy of this ScoreModification.

        :return: The privacy of this ScoreModification.
        :rtype: ScorePrivacy
        """
        return self._privacy

    @privacy.setter
    def privacy(self, privacy):
        """
        Sets the privacy of this ScoreModification.

        :param privacy: The privacy of this ScoreModification.
        :type: ScorePrivacy
        """

        self._privacy = privacy

    @property
    def title(self):
        """
        Gets the title of this ScoreModification.
        A new title of the score

        :return: The title of this ScoreModification.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this ScoreModification.
        A new title of the score

        :param title: The title of this ScoreModification.
        :type: str
        """

        self._title = title

    @property
    def sharing_key(self):
        """
        Gets the sharing_key of this ScoreModification.
        When using the `privacy` mode `privateLink`, this property can be used to set a custom sharing key, otherwise a new key will be generated.

        :return: The sharing_key of this ScoreModification.
        :rtype: str
        """
        return self._sharing_key

    @sharing_key.setter
    def sharing_key(self, sharing_key):
        """
        Sets the sharing_key of this ScoreModification.
        When using the `privacy` mode `privateLink`, this property can be used to set a custom sharing key, otherwise a new key will be generated.

        :param sharing_key: The sharing_key of this ScoreModification.
        :type: str
        """
        if sharing_key is not None and not re.search('^[a-f0-9]{128}$', sharing_key):
            raise ValueError("Invalid value for `sharing_key`, must be a follow pattern or equal to `/^[a-f0-9]{128}$/`")

        self._sharing_key = sharing_key

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ScoreModification):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
